@@ -5,6 +5,7 @@
 # -----------------------------------------------------------------------------
 
 from knack.help_files import helps
+# pylint: disable=line-too-long, anomalous-backslash-in-string
 
 
 helps[''] = """
@@ -114,9 +115,33 @@ helps['test'] = """
           populator-commands:
             - pytest -h
     examples:
+        - name: Run all tests.
+          text: azdev test
+
+        - name: Run tests for main modules.
+          text: azdev test CLI
+
+        - name: Run tests for extensions.
+          text: azdev test EXT
+
         - name: Run tests for specific modules.
           text: azdev test {mod1} {mod2}
 
+        - name: Run tests for specific cli modules, it is recommended to use the long name azure-cli-{mod}.
+          text: azdev test azure-cli-vm azure-cli-compute
+
+        - name: Run tests for specific extensions, it is recommended to use the long name azext_{ext}.
+          text: azdev test azext_containerapp azext_aosm
+
+        - name: Run tests for specific test files.
+          text: azdev test test_account_scenario
+
+        - name: Run tests for specific python class.
+          text: azdev test SubscriptionClientScenarioTest
+
+        - name: Run tests for specific test cases.
+          text: azdev test test_account
+
         - name: Re-run the tests that failed the previous run.
           text: azdev test --lf
 
@@ -135,6 +160,54 @@ helps['linter'] = """
           text: azdev linter --repo azure-cli --tgt upstream/master --src upstream/dev
 """
 
+helps['scan'] = """
+    short-summary: Scan secrets for files or string
+    long-summary: Check built-in scanning rules at https://github.com/microsoft/security-utilities/blob/main/GeneratedRegexPatterns/PreciselyClassifiedSecurityKeys.json
+    examples:
+        - name: Scan secrets for a single file with custom patterns
+          text: |
+                azdev scan --file-path my_file.yaml --custom-pattern my_pattern.json
+                ("my_pattern.json" contains the following content)
+                {
+                    "Include": [
+                        {
+                            "Pattern": "(?<refine>[\w.%#+-]+)(%40|@)([a-z0-9.-]*.[a-z]{2,})",
+                            "Name": "EmailAddress",
+                            "Signatures": ["%40", "@"]
+                        },
+                        {
+                            "Pattern": "(?<refine>[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12})",
+                            "Name": "GUID"
+                        }
+                    ],
+                    "Exclude": [
+                        {
+                            "Id": "SEC101/156",
+                            "Name": "AadClientAppIdentifiableCredentials",
+                        }
+                    ]
+                }
+        - name: Scan secrets for raw string and save results to file
+          text: |
+                azdev scan --data "my string waiting to be scanned" --save-scan-result True
+        - name: Recursively scan secrets for a directory and save results to specific file
+          text: |
+                azdev scan --directory-path /path/to/my/folder --recursive --scan-result-path /path/to/scan_result.json
+        - name: Scan secrets for all json files and yaml files within a directory
+          text: |
+                azdev scan --directory-path /path/to/my/folder --include-pattern *.yaml *.json
+"""
+
+helps['mask'] = """
+    short-summary: Mask secrets for files or string
+    long-summary: |
+                Redaction type 'FIXED_VALUE' will mask all secrets with '***'.
+                Redaction type 'FIXED_LENGTH' will mask secrets with several '*'s which will keep the original secret length.
+                Redaction type 'SECRET_NAME' redaction type will mask secrets with their secret name (type).
+                Redaction type 'CUSTOM' will mask secrets with 'redaction_token' value you specify through saved scan result file.
+                Check built-in scanning rules at https://github.com/microsoft/security-utilities/blob/main/GeneratedRegexPatterns/PreciselyClassifiedSecurityKeys.json
+"""
+
 helps['statistics'] = """
     short-summary: Commands for CLI modules statistics.
 """
@@ -155,6 +228,31 @@ helps['statistics diff-command-tables'] = """
           text: azdev statistics diff-command-tables --table-path command-table_May_01.json --diff-table-path command-table_Oct_01.json --statistics-only
 """
 
+helps['command-change'] = """
+    short-summary: Commands for CLI modules meta data.
+"""
+
+helps['command-change meta-export'] = """
+    short-summary: Export Command meta data for CLI module.
+    examples:
+        - name: Export command meta for the monitor and network module
+          text: azdev command-change meta-export network monitor -o table
+"""
+
+helps['command-change meta-diff'] = """
+    short-summary: Diff the command meta between provided meta files.
+    examples:
+        - name: Diff the command meta change from fileA to fileB
+          text: azdev statistics meta-diff --base-meta-file fileA --diff-meta-file fileB --only-break
+"""
+
+helps['command-change tree-export'] = """
+    short-summary: Export Command Tree for CLI modules or extensions.
+    examples:
+        - name: Export command tree for CLI modules
+          text: azdev command-change tree-export CLI --output-file command_tree.json
+"""
+
 helps['perf'] = """
     short-summary: Commands to test CLI performance.
 """
@@ -209,6 +307,9 @@ helps['extension list'] = """
     short-summary: List what extensions are currently visible to your development environment.
 """
 
+helps['extension show'] = """
+    short-summary: Show detailed extension info that installed in your development environment.
+"""
 
 helps['extension publish'] = """
     short-summary: Build and publish an extension to a storage account.
@@ -224,6 +325,9 @@ helps['extension update-index'] = """
     short-summary: Update the extensions index.json from a built WHL file.
 """
 
+helps['extension cal-next-version'] = """
+    short-summary: Calculate valid version for next extension module release.
+"""
 
 helps['extension repo'] = """
     short-summary: Commands to manage extension repositories for development.
@@ -262,3 +366,14 @@ helps['extension generate-docs'] = """
     long-summary: >
         This command installs the extensions in a temporary directory and sets it as the extensions dir when generating reference docs.
 """
+
+helps['cmdcov'] = """
+    short-summary: Run command test coverage and generate CLI command test coverage report.
+    examples:
+        - name: Check all CLI modules command test coverage.
+          text: azdev cmdcov CLI
+        - name: Check one or serveral modules command test coverage.
+          text: azdev cmdcov vm storage
+        - name: Check CLI modules command test coverage in argument level.
+          text: azdev cmdcov CLI --level argument
+"""
